@@ -1,8 +1,3 @@
-if (getRversion() >= "2.15.1") utils::globalVariables(c('t1',
-                                                        'r1',
-                                                        't2',
-                                                        'r2'))
-
 fra <-
 function(){
   my.draw <- function(panel) {
