@@ -1,9 +1,3 @@
-if (getRversion() >= "2.15.1") utils::globalVariables(c('Notional',
-                                                        'f12',
-                                                        'fixed',
-                                                        't1',
-                                                        't2'))
-
 fravalue <-
 function(){
   my.draw <- function(panel) {
