@@ -1,8 +1,3 @@
-if (getRversion() >= "2.15.1") utils::globalVariables(c('tkrp',
-                                                        'longput',
-                                                        'longcall',
-                                                        'profit'))
-
 strangle <-
 function(){
   
